@@ -35,6 +35,7 @@
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 #include <stdlib.h>
+#include <pango/pangoxft.h>
 
 #define GRADIENT_BAND_SIZE 4
 
@@ -731,6 +732,26 @@ eel_gdk_parse_geometry (const char *string, int *x_return, int *y_return,
 	return gdk_flags;
 }
 
+void
+eel_gdk_draw_layout_with_drop_shadow (GdkDrawable         *drawable,
+				      GdkGC               *gc,
+				      GdkColor            *text_color,
+				      GdkColor            *shadow_color,
+				      int                  x,
+				      int                  y,
+				      PangoLayout         *layout)
+{
+	gdk_draw_layout_with_colors (drawable, gc,
+				     x+1, y+1,
+				     layout,
+				     shadow_color, NULL);
+	
+	gdk_draw_layout_with_colors (drawable, gc,
+				     x, y,
+				     layout,
+				     text_color, NULL);
+}
+
 /* Color specifications have changed in gdk 2.0.  Unfortunately, nautilus has
    the old rgb:RRRR/BBBB/GGGG format scattered about in various xml files and
    the new gdk_color_parse () is not fully backward compatible. */
