@@ -30,9 +30,10 @@
 #include "eel-debug.h"
 #include "eel-lib-self-check-functions.h"
 #include "eel-string.h"
+#include <glib-object.h>
 #include <libgnome/gnome-i18n.h>
-#include <stdlib.h>
 #include <math.h>
+#include <stdlib.h>
 #include <sys/time.h>
 #include <sys/utsname.h>
 #include <time.h>
@@ -841,6 +842,113 @@ eel_compare_integer (gconstpointer a,
 	return int_a < int_b ? -1 : 1;
 }
 
+/**
+ * eel_g_object_list_ref
+ *
+ * Ref all the objects in a list.
+ * @list: GList of objects.
+ **/
+GList *
+eel_g_object_list_ref (GList *list)
+{
+	g_list_foreach (list, (GFunc) g_object_ref, NULL);
+	return list;
+}
+
+/**
+ * eel_g_object_list_unref
+ *
+ * Unref all the objects in a list.
+ * @list: GList of objects.
+ **/
+void
+eel_g_object_list_unref (GList *list)
+{
+	g_list_foreach (list, (GFunc) g_object_unref, NULL);
+}
+
+/**
+ * eel_g_object_list_free
+ *
+ * Free a list of objects after unrefing them.
+ * @list: GList of objects.
+ **/
+void
+eel_g_object_list_free (GList *list)
+{
+	eel_g_object_list_unref (list);
+	g_list_free (list);
+}
+
+/**
+ * eel_g_object_list_copy
+ *
+ * Copy the list of objects, ref'ing each one.
+ * @list: GList of objects.
+ **/
+GList *
+eel_g_object_list_copy (GList *list)
+{
+	return g_list_copy (eel_g_object_list_ref (list));
+}
+
+/**
+ * eel_add_weak_pointer
+ *
+ * Nulls out a saved reference to an object when the object gets destroyed.
+ *
+ * @pointer_location: Address of the saved pointer.
+ **/
+void 
+eel_add_weak_pointer (gpointer pointer_location)
+{
+	gpointer *object_location;
+
+	g_return_if_fail (pointer_location != NULL);
+
+	object_location = (gpointer *) pointer_location;
+	if (*object_location == NULL) {
+		/* The reference is NULL, nothing to do. */
+		return;
+	}
+
+	g_return_if_fail (G_IS_OBJECT (*object_location));
+
+	g_object_add_weak_pointer (G_OBJECT (*object_location),
+				   object_location);
+}
+
+/**
+ * eel_remove_weak_pointer
+ *
+ * Removes the weak pointer that was added by eel_add_weak_pointer.
+ * Also nulls out the pointer.
+ *
+ * @pointer_location: Pointer that was passed to eel_add_weak_pointer.
+ **/
+void 
+eel_remove_weak_pointer (gpointer pointer_location)
+{
+	gpointer *object_location;
+
+	g_return_if_fail (pointer_location != NULL);
+
+	object_location = (gpointer *) pointer_location;	
+	if (*object_location == NULL) {
+		/* The object was already destroyed and the reference
+		 * nulled out, nothing to do.
+		 */
+		return;
+	}
+
+	g_return_if_fail (G_IS_OBJECT (*object_location));
+
+	g_object_remove_weak_pointer (G_OBJECT (*object_location),
+				      object_location);
+	
+	*object_location = NULL;
+}
+
 #if !defined (EEL_OMIT_SELF_CHECK)
 
 static void 
