@@ -943,8 +943,8 @@ enumeration_menu_changed_callback (EelStringPicker *string_picker,
  	selected_label = eel_string_picker_get_selected_string (string_picker);
 	g_return_if_fail (selected_label != NULL);
 
-	position = eel_enumeration_id_get_description_position (enumeration_id,
-								selected_label);
+	position = eel_string_picker_get_index_for_string (string_picker,
+							   selected_label);
 	g_free (selected_label);
 	g_return_if_fail (position != EEL_STRING_LIST_NOT_FOUND);
 	
@@ -989,8 +989,8 @@ enumeration_list_changed_callback (EelStringPicker *string_picker,
 		selected_label = eel_string_picker_get_selected_string (EEL_STRING_PICKER (connection->widget));
 		g_return_if_fail (selected_label != NULL);
 
-		position = eel_enumeration_id_get_description_position (enumeration_id,
-									selected_label);
+		position = eel_string_picker_get_index_for_string (EEL_STRING_PICKER (connection->widget),
+								   selected_label);
 		g_free (selected_label);
 		g_return_if_fail (position != EEL_STRING_LIST_NOT_FOUND);
 		
